@@ -3,12 +3,13 @@
 # Import the llvm-py modules.
 from llvm import *
 from llvm.core import *
+from llvm.test_llvmpy import TestCase
 
 import logging
 import unittest
 
 
-class TestInlineAsm(unittest.TestCase):
+class TestInlineAsm(TestCase):
     def test_inline_asm(self):
         mod = Module.new(__name__)
         fnty = Type.function(Type.int(), [Type.int()])
